## 当日集合竞价

接口：stk_auction

描述：获取当日个股和ETF的集合竞价成交情况，每天9点25~29分之间可以获取当日的集合竞价成交数据

限量：单次最大返回8000行数据，可根据日期或代码循环获取历史

积分：本接口是单独开权限的数据，已经开通了股票分钟权限的用户可自动获得本接口权限，单独申请权限请参考权限列表。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码 |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同) |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 股票代码 |
| trade_date | str | Y | 数据日期 |
| vol | int | Y | 成交量（股） |
| price | int | Y | 成交均价（元） |
| amount | float | Y | 成交金额（元） |
| pre_close | float | Y | 昨收价（元） |
| turnover_rate | float | Y | 换手率（%） |
| volume_ratio | float | Y | 量比 |
| float_share | float | Y | 流通股本（万股） |

接口示例

```python
#获取2025年2月18日开盘集合竞价成交情况
df = pro.stk_auction(trade_date='20250218',fields='ts_code, trade_date,vol,price,amount,turnover_rate,volume_ratio')
```

数据示例

```python
ts_code trade_date     vol    price      amount  turnover_rate  volume_ratio
0     600071.SH   20250218    8700   23.240   202188.00       0.003090      0.150628
```